@@ -15,6 +15,7 @@ import warnings
 
 import numpy as np
 import scipy.sparse as sp
+from threadpoolctl import threadpool_limits
 
 from sklearn.base import BaseEstimator, ClusterMixin, TransformerMixin
 from sklearn.metrics.pairwise import euclidean_distances
@@ -179,11 +180,12 @@ def _check_normalize_sample_weight(sample_weight, X):
         # an array of 1 (i.e. samples_weight is None) is already normalized
         n_samples = len(sample_weight)
         scale = n_samples / sample_weight.sum()
-        sample_weight *= scale
+        sample_weight = sample_weight * scale
     return sample_weight
 
 
-def k_means(X, n_clusters, sample_weight=None, init='k-means++',
+@_deprecate_positional_args
+def k_means(X, n_clusters, *, sample_weight=None, init='k-means++',
             precompute_distances='deprecated', n_init=10, max_iter=300,
             verbose=False, tol=1e-4, random_state=None, copy_x=True,
             n_jobs='deprecated', algorithm="auto", return_n_iter=False):
@@ -436,15 +438,16 @@ def _kmeans_single_elkan(X, sample_weight, n_clusters, max_iter=300,
                 labels, upper_bounds, lower_bounds)
 
     for i in range(max_iter):
-        elkan_iter(X, sample_weight, centers, centers_new, weight_in_clusters,
-                   center_half_distances, distance_next_center, upper_bounds,
-                   lower_bounds, labels, center_shift, n_threads)
+        elkan_iter(X, sample_weight, centers, centers_new,
+                   weight_in_clusters, center_half_distances,
+                   distance_next_center, upper_bounds, lower_bounds,
+                   labels, center_shift, n_threads)
 
         # compute new pairwise distances between centers and closest other
         # center of each center for next iterations
         center_half_distances = euclidean_distances(centers_new) / 2
-        distance_next_center = np.partition(np.asarray(center_half_distances),
-                                            kth=1, axis=0)[1]
+        distance_next_center = np.partition(
+            np.asarray(center_half_distances), kth=1, axis=0)[1]
 
         if verbose:
             inertia = _inertia(X, sample_weight, centers, labels)
@@ -463,9 +466,9 @@ def _kmeans_single_elkan(X, sample_weight, n_clusters, max_iter=300,
     if center_shift_tot > 0:
         # rerun E-step so that predicted labels match cluster centers
         elkan_iter(X, sample_weight, centers, centers, weight_in_clusters,
-                   center_half_distances, distance_next_center, upper_bounds,
-                   lower_bounds, labels, center_shift, n_threads,
-                   update_centers=False)
+                   center_half_distances, distance_next_center,
+                   upper_bounds, lower_bounds, labels, center_shift,
+                   n_threads, update_centers=False)
 
     inertia = _inertia(X, sample_weight, centers, labels)
 
@@ -569,29 +572,32 @@ def _kmeans_single_lloyd(X, sample_weight, n_clusters, max_iter=300,
         lloyd_iter = lloyd_iter_chunked_dense
         _inertia = _inertia_dense
 
-    for i in range(max_iter):
-        lloyd_iter(X, sample_weight, x_squared_norms, centers, centers_new,
-                   weight_in_clusters, labels, center_shift, n_threads)
+    # Threadpoolctl context to limit the number of threads in second level of
+    # nested parallelism (i.e. BLAS) to avoid oversubsciption.
+    with threadpool_limits(limits=1, user_api="blas"):
+        for i in range(max_iter):
+            lloyd_iter(X, sample_weight, x_squared_norms, centers, centers_new,
+                       weight_in_clusters, labels, center_shift, n_threads)
 
-        if verbose:
-            inertia = _inertia(X, sample_weight, centers, labels)
-            print("Iteration {0}, inertia {1}" .format(i, inertia))
-
-        center_shift_tot = (center_shift**2).sum()
-        if center_shift_tot <= tol:
             if verbose:
-                print("Converged at iteration {0}: "
-                      "center shift {1} within tolerance {2}"
-                      .format(i, center_shift_tot, tol))
-            break
+                inertia = _inertia(X, sample_weight, centers, labels)
+                print("Iteration {0}, inertia {1}" .format(i, inertia))
 
-        centers, centers_new = centers_new, centers
+            center_shift_tot = (center_shift**2).sum()
+            if center_shift_tot <= tol:
+                if verbose:
+                    print("Converged at iteration {0}: "
+                          "center shift {1} within tolerance {2}"
+                          .format(i, center_shift_tot, tol))
+                break
 
-    if center_shift_tot > 0:
-        # rerun E-step so that predicted labels match cluster centers
-        lloyd_iter(X, sample_weight, x_squared_norms, centers, centers,
-                   weight_in_clusters, labels, center_shift, n_threads,
-                   update_centers=False)
+            centers, centers_new = centers_new, centers
+
+        if center_shift_tot > 0:
+            # rerun E-step so that predicted labels match cluster centers
+            lloyd_iter(X, sample_weight, x_squared_norms, centers, centers,
+                       weight_in_clusters, labels, center_shift, n_threads,
+                       update_centers=False)
 
     inertia = _inertia(X, sample_weight, centers, labels)
 
